@@ -1,4 +1,4 @@
-# $Id: Constraints.pm 520 2005-06-09 01:42:45Z claco $
+# $Id: Constraints.pm 697 2005-08-10 01:29:51Z claco $
 package Handel::Constraints;
 use strict;
 use warnings;
@@ -6,8 +6,8 @@ use vars qw(@EXPORT_OK %EXPORT_TAGS);
 
 BEGIN {
     use base 'Exporter';
-    use Handel::ConfigReader;
-    use Handel::Constants qw(:cart :checkout);
+    use Handel;
+    use Handel::Constants qw(:cart :checkout :order);
     use Handel::Exception;
     use Handel::L10N qw(translate);
 };
@@ -18,6 +18,7 @@ BEGIN {
                 &constraint_cart_type
                 &constraint_currency_code
                 &constraint_checkout_phase
+                &constraint_order_type
 );
 
 %EXPORT_TAGS = (all => \@EXPORT_OK);
@@ -28,7 +29,7 @@ sub constraint_quantity {
     my $value = defined $_[0] ? shift : '';
     my ($object, $column, $changing) = @_;
 
-    my $cfg    = Handel::ConfigReader->new();
+    my $cfg    = $Handel::Cfg;
     my $max    = $cfg->{'HandelMaxQuantity'};
     my $action = $cfg->{'HandelMaxQuantityAction'};
 
@@ -101,6 +102,17 @@ sub constraint_checkout_phase {
     return 1;
 };
 
+sub constraint_order_type {
+    my $value = defined $_[0] ? shift : '';
+
+    return if $value !~ /[0-9]/;
+
+    if ($value != ORDER_TYPE_SAVED && $value != ORDER_TYPE_TEMP) {
+        return 0;
+    };
+    return 1;
+};
+
 1;
 __END__
 
@@ -172,6 +184,11 @@ conforms to:
 Returns 1 if the value passed is one of the C<CHECKOUT_PHASE_*> constants,
 otherwise it returns C<undef>.
 
+=head2 constraint_order_type
+
+Returns 1 if the value passed is C<ORDER_TYPE_SAVED> or C<ORDER_TYPE_TEMP>,
+otherwise it returns C<undef>.
+
 =head1 EXPORT_TAGS
 
 =head2 :all
