@@ -1,16 +1,16 @@
-# $Id: DBI.pm 521 2005-06-09 01:43:13Z claco $
+# $Id: DBI.pm 699 2005-08-10 01:30:21Z claco $
 package Handel::DBI;
 use strict;
 use warnings;
 
 BEGIN {
     use base 'Class::DBI';
-    use Handel::ConfigReader;
+    use Handel;
     use Handel::Exception;
     use Handel::L10N qw(translate);
 };
 
-my $cfg = Handel::ConfigReader->new();
+my $cfg = $Handel::Cfg;
 my $db_driver  = $cfg->{'HandelDBIDriver'}   || $cfg->{'db_driver'};
 my $db_host    = $cfg->{'HandelDBIHost'}     || $cfg->{'db_host'};
 my $db_port    = $cfg->{'HandelDBIPort'}     || $cfg->{'db_port'};
